==========
OASIS_stat
==========


.. image:: https://img.shields.io/pypi/v/oasis_stat.svg
        :target: https://pypi.python.org/pypi/oasis_stat

.. image:: https://readthedocs.org/projects/oasis-stat/badge/?version=latest
        :target: https://oasis-stat.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




OASIS statistical test for interpretable analysis of contingency tables.


* Free software: MIT license
* Documentation: https://oasis-stat.readthedocs.io.


Features
--------

* OASIS statistical test from https://www.pnas.org/doi/10.1073/pnas.2304671121. Initial commit for pypi package.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
